===============================
NetworkX to Neo4j
===============================

.. image:: https://badge.fury.io/py/neonx.png
    :target: http://badge.fury.io/py/neonx

.. image:: https://travis-ci.org/ducky427/neonx.png?branch=master
        :target: https://travis-ci.org/ducky427/neonx

.. image:: https://pypip.in/d/neonx/badge.png
        :target: https://crate.io/packages/neonx?version=latest

.. image:: https://coveralls.io/repos/ducky427/neonx/badge.png?branch=master
        :target: https://coveralls.io/r/ducky427/neonx?branch=master


A library to convert a `NetworkX <http://networkx.github.io/>`_ graph to a `Neo4j <http://www.neo4j.org>`_ graph.


Other information:

* Free software: MIT license.
* Documentation: http://neonx.rtfd.org.

Features
--------

* Converts a `NetworkX <http://networkx.github.io/>`_ graph to a `Geoff <http://book.py2neo.org/en/latest/geoff/>`_ compatible string.

* Upload a `NetworkX <http://networkx.github.io/>`_ graph to Neo4j server using `Requests <https://pypi.python.org/pypi/requests>`_.